.. octomachinery documentation master file, created by
   sphinx-quickstart on Tue Mar 12 14:26:59 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

|project|: the octobots engine
==============================

.. include:: ../README.rst
   :end-before: DO-NOT-REMOVE-docs-badges-END

.. include:: ../README.rst
   :start-after: DO-NOT-REMOVE-docs-intro-START

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   getting-started
   howto-guides



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
